package
Version:
v1.1.2
Opens a new window with list of versions in this module.
Published: Jan 25, 2024
License: BSD-2-Clause
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ClientConfig struct {
RootCA string `json:"RootCA"`
CLientCrt string `json:"CLientCrt"`
ClientKey string `json:"ClientKey"`
Port uint16 `json:"Port"`
Server string `json:"Server"`
}
type ServerOptions struct {
RootCA string `json:"RootCA"`
ServerCrt string `json:"ServerCrt"`
ServerKey string `json:"ServerKey"`
Port uint16 `json:"Port"`
Listen string `json:"Listen"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.